# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import af_licence_manager
from af_licence_manager.api.licence_manager_api import LicenceManagerApi  # noqa: E501
from af_licence_manager.rest import ApiException


class TestLicenceManagerApi(unittest.TestCase):
    """LicenceManagerApi unit test stubs"""

    def setUp(self):
        self.api = LicenceManagerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_licence_information(self):
        """Test case for get_licence_information

        """
        pass


if __name__ == '__main__':
    unittest.main()
