# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EbpInstanceReference(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'instance_id': 'str',
        'instance_log_id': 'str',
        'base_template_id': 'str',
        'node_id': 'int',
        'node_iteration': 'int',
        'execution_manager_uris': 'list[str]',
        'runtime_manager_uris': 'list[str]'
    }

    attribute_map = {
        'type': 'type',
        'instance_id': 'instanceId',
        'instance_log_id': 'instanceLogId',
        'base_template_id': 'baseTemplateId',
        'node_id': 'nodeId',
        'node_iteration': 'nodeIteration',
        'execution_manager_uris': 'executionManagerUris',
        'runtime_manager_uris': 'runtimeManagerUris'
    }

    def __init__(self, type=None, instance_id=None, instance_log_id=None, base_template_id=None, node_id=None, node_iteration=None, execution_manager_uris=None, runtime_manager_uris=None):  # noqa: E501
        """EbpInstanceReference - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._instance_id = None
        self._instance_log_id = None
        self._base_template_id = None
        self._node_id = None
        self._node_iteration = None
        self._execution_manager_uris = None
        self._runtime_manager_uris = None
        if not(hasattr(self, "discriminator")) or not(self.discriminator):
            self.discriminator = None
        self.type = type
        self.instance_id = instance_id
        self.instance_log_id = instance_log_id
        self.base_template_id = base_template_id
        self.node_id = node_id
        self.node_iteration = node_iteration
        self.execution_manager_uris = execution_manager_uris
        if runtime_manager_uris is not None:
            self.runtime_manager_uris = runtime_manager_uris

    @property
    def type(self):
        """Gets the type of this EbpInstanceReference.  # noqa: E501


        :return: The type of this EbpInstanceReference.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EbpInstanceReference.


        :param type: The type of this EbpInstanceReference.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["NULL", "ACTIVITY", "DECISION_ACTIVITY", "LWP", "TLPI"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def instance_id(self):
        """Gets the instance_id of this EbpInstanceReference.  # noqa: E501


        :return: The instance_id of this EbpInstanceReference.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this EbpInstanceReference.


        :param instance_id: The instance_id of this EbpInstanceReference.  # noqa: E501
        :type: str
        """
        if instance_id is None:
            raise ValueError("Invalid value for `instance_id`, must not be `None`")  # noqa: E501

        self._instance_id = instance_id

    @property
    def instance_log_id(self):
        """Gets the instance_log_id of this EbpInstanceReference.  # noqa: E501


        :return: The instance_log_id of this EbpInstanceReference.  # noqa: E501
        :rtype: str
        """
        return self._instance_log_id

    @instance_log_id.setter
    def instance_log_id(self, instance_log_id):
        """Sets the instance_log_id of this EbpInstanceReference.


        :param instance_log_id: The instance_log_id of this EbpInstanceReference.  # noqa: E501
        :type: str
        """
        if instance_log_id is None:
            raise ValueError("Invalid value for `instance_log_id`, must not be `None`")  # noqa: E501

        self._instance_log_id = instance_log_id

    @property
    def base_template_id(self):
        """Gets the base_template_id of this EbpInstanceReference.  # noqa: E501


        :return: The base_template_id of this EbpInstanceReference.  # noqa: E501
        :rtype: str
        """
        return self._base_template_id

    @base_template_id.setter
    def base_template_id(self, base_template_id):
        """Sets the base_template_id of this EbpInstanceReference.


        :param base_template_id: The base_template_id of this EbpInstanceReference.  # noqa: E501
        :type: str
        """
        if base_template_id is None:
            raise ValueError("Invalid value for `base_template_id`, must not be `None`")  # noqa: E501

        self._base_template_id = base_template_id

    @property
    def node_id(self):
        """Gets the node_id of this EbpInstanceReference.  # noqa: E501


        :return: The node_id of this EbpInstanceReference.  # noqa: E501
        :rtype: int
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this EbpInstanceReference.


        :param node_id: The node_id of this EbpInstanceReference.  # noqa: E501
        :type: int
        """
        if node_id is None:
            raise ValueError("Invalid value for `node_id`, must not be `None`")  # noqa: E501

        self._node_id = node_id

    @property
    def node_iteration(self):
        """Gets the node_iteration of this EbpInstanceReference.  # noqa: E501


        :return: The node_iteration of this EbpInstanceReference.  # noqa: E501
        :rtype: int
        """
        return self._node_iteration

    @node_iteration.setter
    def node_iteration(self, node_iteration):
        """Sets the node_iteration of this EbpInstanceReference.


        :param node_iteration: The node_iteration of this EbpInstanceReference.  # noqa: E501
        :type: int
        """
        if node_iteration is None:
            raise ValueError("Invalid value for `node_iteration`, must not be `None`")  # noqa: E501

        self._node_iteration = node_iteration

    @property
    def execution_manager_uris(self):
        """Gets the execution_manager_uris of this EbpInstanceReference.  # noqa: E501


        :return: The execution_manager_uris of this EbpInstanceReference.  # noqa: E501
        :rtype: list[str]
        """
        return self._execution_manager_uris

    @execution_manager_uris.setter
    def execution_manager_uris(self, execution_manager_uris):
        """Sets the execution_manager_uris of this EbpInstanceReference.


        :param execution_manager_uris: The execution_manager_uris of this EbpInstanceReference.  # noqa: E501
        :type: list[str]
        """
        if execution_manager_uris is None:
            raise ValueError("Invalid value for `execution_manager_uris`, must not be `None`")  # noqa: E501

        self._execution_manager_uris = execution_manager_uris

    @property
    def runtime_manager_uris(self):
        """Gets the runtime_manager_uris of this EbpInstanceReference.  # noqa: E501


        :return: The runtime_manager_uris of this EbpInstanceReference.  # noqa: E501
        :rtype: list[str]
        """
        return self._runtime_manager_uris

    @runtime_manager_uris.setter
    def runtime_manager_uris(self, runtime_manager_uris):
        """Sets the runtime_manager_uris of this EbpInstanceReference.


        :param runtime_manager_uris: The runtime_manager_uris of this EbpInstanceReference.  # noqa: E501
        :type: list[str]
        """

        self._runtime_manager_uris = runtime_manager_uris

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EbpInstanceReference, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EbpInstanceReference):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
