# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import af_licence_manager
from af_licence_manager.api.arista_flow_service_api import AristaFlowServiceApi  # noqa: E501
from af_licence_manager.rest import ApiException


class TestAristaFlowServiceApi(unittest.TestCase):
    """AristaFlowServiceApi unit test stubs"""

    def setUp(self):
        self.api = AristaFlowServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_release(self):
        """Test case for get_release

        """
        pass

    def test_get_service_instance_name(self):
        """Test case for get_service_instance_name

        """
        pass

    def test_get_uris(self):
        """Test case for get_uris

        """
        pass

    def test_ping(self):
        """Test case for ping

        """
        pass

    def test_register_sse(self):
        """Test case for register_sse

        """
        pass

    def test_unregister_sse(self):
        """Test case for unregister_sse

        """
        pass


if __name__ == '__main__':
    unittest.main()
